@@ -3,7 +3,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '0.005000'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 use Moose;
 with (
@@ -110,7 +110,7 @@ Dist::Zilla::Plugin::OurPkgVersion - no line insertion and does Package version
 
 =head1 VERSION
 
-version 0.005000
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -227,19 +227,61 @@ tells which files to munge, see L<Dist::Zilla::Role::FileMunger>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/xenoterracide/dist-zilla-plugin-ourpkgversion/issues
+https://github.com/plicease/dist-zilla-plugin-ourpkgversion/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
+=head1 CONTRIBUTORS
+
+=for stopwords Alexandr Ciornii Alexei Znamensky Christian Walde Christopher J. Madsen David Golden Graham Ollis
+
+=over 4
+
+=item *
+
+Alexandr Ciornii <alexchorny@gmail.com>
+
+=item *
+
+Alexei Znamensky <russoz@cpan.org>
+
+=item *
+
+Christian Walde <walde.christian@googlemail.com>
+
+=item *
+
+Christopher J. Madsen <perl@cjmweb.net>
+
+=item *
+
+David Golden <dagolden@cpan.org>
+
+=item *
+
+Graham Ollis <perl@wdlabs.com>
+
+=back
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Caleb Cushing <xenoterracide@gmail.com>
 
+=item *
+
+Grahan Ollis <plicease@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Caleb Cushing.
+This software is Copyright (c) 2015 by Caleb Cushing.
 
 This is free software, licensed under:
 
